<?php
/**
 * Perforce Swarm
 *
 * @copyright   2013-2025 Perforce Software. All rights reserved.
 * @license     Please see LICENSE.txt in top-level readme folder of this distribution.
 * @version     2025.1/2745343
 */

use AiAnalysis\AiAnalysisCharLimitChecker;
use AiAnalysis\AiAnalysisChecker;
use AiAnalysis\Factory\AiServiceFactory;
use AiAnalysis\Filter\AiAnalysis;
use AiAnalysis\Filter\DiscardAnalysis;
use AiAnalysis\Filter\IAiAnalysis;
use AiAnalysis\Model\AiAnalysisDAO;
use AiAnalysis\Model\IAiReviewSummary;
use AiAnalysis\Service\GenericAIAdapter;
use AiAnalysis\Service\OpenAIAdapter;
use Api\Controller\IndexController;
use Api\IRequest;
use Application\Checker;
use Application\Config\IConfigDefinition;
use Application\Config\IDao;
use Application\Config\Services;
use Application\Controller\IndexControllerFactory;
use AiAnalysis\Controller\AiAnalysisApi;
use Application\Factory\InvokableServiceFactory;
use Laminas\Http\Request;
use Laminas\Router\Http\Segment;

return [
    IConfigDefinition::AI_REVIEW => [
        IConfigDefinition::AI_VENDORS => [
            IConfigDefinition::AI_MODEL1 => [
                IConfigDefinition::AI_VENDOR => 'openAI',
                IConfigDefinition::AI_PACKAGE_ID => 1,
                IConfigDefinition::AI_PACKAGE_KEY => 'openaiwithexplaincodeongpt4',
                IConfigDefinition::AI_PACKAGE_VALUE => 'Open AI With Explain Code On GPT4',
                IConfigDefinition::AI_MODEL => 'gpt-4',
                IConfigDefinition::AI_PACKAGE_TYPE => 'Explain the following code',
                IConfigDefinition::API_KEY => 'openAI',
                IConfigDefinition::AI_MIN_CHAR_LIMIT => 4,
                IConfigDefinition::AI_MAX_CHAR_LIMIT => 31000,
                IConfigDefinition::API_END_POINT => '',
            ]
        ],
        IConfigDefinition::ENABLED => false,
    ],
    'router' => [
        'routes' => [
            'api' => [
                'type' => 'literal',
                'options' => [
                    'route' => IndexController::API_BASE,
                ],
                'may_terminate' => false,
                'child_routes' => [
                    'AiAnalysis' => [
                        'type' => Segment::class,
                        'options' => [
                            'route' => '/:version/AiAnalysis',
                            'constraints' => [IRequest::VERSION => 'v11'],
                            'defaults' => [
                                'controller' => AiAnalysisApi::class
                            ],
                        ],
                        'child_routes' => [
                            'AiAnalysis-analyze' => [
                                'type' => Segment::class,
                                'options' => [
                                    'route' => '/analyzeCode',
                                    'verb' => Request::METHOD_POST,
                                    'defaults' => [
                                        'action' => 'analyzeCode'
                                    ],
                                ],
                            ],
                            'AiAnalysis-getAiPackageDetails' => [
                                'type' => Segment::class,
                                'options' => [
                                    'route' => '/getAiPackageDetails',
                                    'verb' => Request::METHOD_GET,
                                    'defaults' => [
                                        'action' => 'getAiPackageDetails'
                                    ],
                                ],
                            ],
                            'AiAnalysis-discard' => [
                                'type' => Segment::class,
                                'options' => [
                                    'route' => '/discard',
                                    'verb' => Request::METHOD_DELETE,
                                    'defaults' => [
                                        'action' => 'discard'
                                    ],
                                ],
                            ],
                        ],
                    ],
                ]
            ]
        ]
    ],
    'service_manager' => [
        'aliases' => [
            IDao::AI_ANALYSIS_DAO  => AiAnalysisDAO::class,
            AiServiceFactory::OPENAIADAPTER => OpenAIAdapter::class,
            AiServiceFactory::GENERICAIADAPTER => GenericAIAdapter::class,
            IAiAnalysis::NAME => AiAnalysis::class,
            IAiAnalysis::DISCARD_ANALYSIS_FILTER => DiscardAnalysis::class,
        ],
        'factories' => [
                AiAnalysisDAO::class => InvokableServiceFactory::class,
                OpenAIAdapter::class => AiServiceFactory::class,
                Services::OPEN_AI => OpenAIAdapter::class,
                GenericAIAdapter::class => AiServiceFactory::class,
                Services::GENERIC_AI => GenericAIAdapter::class,
                AiAnalysis::class => InvokableServiceFactory::class,
                AiAnalysisChecker::class => InvokableServiceFactory::class,
                AiAnalysisCharLimitChecker::class => InvokableServiceFactory::class,
                DiscardAnalysis::class => InvokableServiceFactory::class,
        ],
    ],
    'controllers' => [
        'factories' => [
            AiAnalysisApi::class => IndexControllerFactory::class,
        ]
    ],
    /**
     * Map a check name of IAiReviewSummary::AI_ANALYSIS to be handled by AiAnalysisChecker
     * Map a check name of IAiReviewSummary::AI_ANALYSIS_CHAR_LIMIT to be handled by AiAnalysisCharLimitChecker
     * @see ConfigCheck
     */
    Checker::CHECKERS => [
        IAiReviewSummary::AI_ANALYSIS => AiAnalysisChecker::class,
        IAiReviewSummary::AI_ANALYSIS_CHAR_LIMIT => AiAnalysisCharLimitChecker::class
    ]
];
